==> ministra-5.6.8.zip: stalker_portal/server/Lib/RESTAPI/v1/RESTCommandAccountSubscription.php <==
<?php

namespace Ministra\Lib\RESTAPI\v1;

use Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a;
use Ministra\Lib\User;
class RESTCommandAccountSubscription extends \Ministra\Lib\RESTAPI\v1\RESTCommand
{
    public function get(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::u22e4c4922dc9d36bddf4890aa8adbdfb($identifiers);
        } else {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::e1e14c0fad3bf8c93dd90e5e3556e7a8e($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = [];
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $result[] = ['mac' => $user->getMac(), 'subscribed' => $info['subscribed'], 'subscribed_id' => $info['subscribed_id']];
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function create(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP POST data is empty');
        }
        $account = \array_intersect_key($data, ['subscribed' => true, 'subscribed_id' => true]);
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::u22e4c4922dc9d36bddf4890aa8adbdfb($identifiers);
        } else {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::e1e14c0fad3bf8c93dd90e5e3556e7a8e($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $subscribe = empty($data['subscribed']) ? [] : \array_unique($data['subscribed']);
            $subscribe_id = empty($data['subscribed_id']) ? [] : $data['subscribed_id'];
            $unsubscribe = empty($data['subscribed']) ? [] : \array_diff($info['subscribed'], $data['subscribed']);
            $unsubscribe_id = empty($data['subscribed_id']) ? [] : \array_diff($info['subscribed_id'], $data['subscribed_id']);
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => $subscribe, 'subscribe_ids' => $subscribe_id, 'unsubscribe' => $unsubscribe, 'unsubscribe_ids' => $unsubscribe_id]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function update(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP PUT data is empty');
        }
        $account = \array_intersect_key($data, ['subscribed' => true, 'subscribed_id' => true, 'unsubscribed' => true, 'unsubscribed_id' => true]);
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::u22e4c4922dc9d36bddf4890aa8adbdfb($identifiers);
        } else {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::e1e14c0fad3bf8c93dd90e5e3556e7a8e($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $subscribed = empty($data['subscribed']) ? [] : $data['subscribed'];
        $subscribed_id = empty($data['subscribed_id']) ? [] : $data['subscribed_id'];
        $unsubscribed = empty($data['unsubscribed']) ? [] : $data['unsubscribed'];
        $unsubscribed_id = empty($data['unsubscribed_id']) ? [] : $data['unsubscribed_id'];
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => $subscribed, 'subscribe_ids' => $subscribed_id, 'unsubscribe' => $unsubscribed, 'unsubscribe_ids' => $unsubscribed_id]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function delete(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::u22e4c4922dc9d36bddf4890aa8adbdfb($identifiers);
        } else {
            $users_ids = \Ministra\Lib\e7ad172977eb8d4fc1927f1037c2a8f5\w3071184ed28647d5b719a759c2f6492a::e1e14c0fad3bf8c93dd90e5e3556e7a8e($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => [], 'unsubscribe' => $info['subscribed']]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
}

==> ministra-5.6.10.zip: stalker_portal/server/Lib/RESTAPI/v1/RESTCommandAccountSubscription.php <==
<?php

namespace Ministra\Lib\RESTAPI\v1;

use Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca;
use Ministra\Lib\User;
class RESTCommandAccountSubscription extends \Ministra\Lib\RESTAPI\v1\RESTCommand
{
    public function get(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::a99a6219e3aa73db583b4cfdd1d2732e($identifiers);
        } else {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::I2aef3bc6863443d8a6a7a7de0b651d20($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = [];
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $result[] = ['mac' => $user->getMac(), 'subscribed' => $info['subscribed'], 'subscribed_id' => $info['subscribed_id']];
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function create(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP POST data is empty');
        }
        $account = \array_intersect_key($data, ['subscribed' => true, 'subscribed_id' => true]);
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::a99a6219e3aa73db583b4cfdd1d2732e($identifiers);
        } else {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::I2aef3bc6863443d8a6a7a7de0b651d20($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $subscribe = empty($data['subscribed']) ? [] : \array_unique($data['subscribed']);
            $subscribe_id = empty($data['subscribed_id']) ? [] : $data['subscribed_id'];
            $unsubscribe = empty($data['subscribed']) ? [] : \array_diff($info['subscribed'], $data['subscribed']);
            $unsubscribe_id = empty($data['subscribed_id']) ? [] : \array_diff($info['subscribed_id'], $data['subscribed_id']);
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => $subscribe, 'subscribe_ids' => $subscribe_id, 'unsubscribe' => $unsubscribe, 'unsubscribe_ids' => $unsubscribe_id]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function update(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $data = $request->getData();
        if (empty($data)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('HTTP PUT data is empty');
        }
        $account = \array_intersect_key($data, ['subscribed' => true, 'subscribed_id' => true, 'unsubscribed' => true, 'unsubscribed_id' => true]);
        if (empty($account)) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Insert data is empty');
        }
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::a99a6219e3aa73db583b4cfdd1d2732e($identifiers);
        } else {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::I2aef3bc6863443d8a6a7a7de0b651d20($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $subscribed = empty($data['subscribed']) ? [] : $data['subscribed'];
        $subscribed_id = empty($data['subscribed_id']) ? [] : $data['subscribed_id'];
        $unsubscribed = empty($data['unsubscribed']) ? [] : $data['unsubscribed'];
        $unsubscribed_id = empty($data['unsubscribed_id']) ? [] : $data['unsubscribed_id'];
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => $subscribed, 'subscribe_ids' => $subscribed_id, 'unsubscribe' => $unsubscribed, 'unsubscribe_ids' => $unsubscribed_id]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
    public function delete(\Ministra\Lib\RESTAPI\v1\RESTRequest $request)
    {
        $identifiers = $request->getIdentifiers();
        if (!empty($identifiers[0]) && \strlen($identifiers[0]) >= 12) {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::a99a6219e3aa73db583b4cfdd1d2732e($identifiers);
        } else {
            $users_ids = \Ministra\Lib\k43ef11a9578c2293bdfdd714ecc1b172\g974965637b063c004a1dfc7c145520ca::I2aef3bc6863443d8a6a7a7de0b651d20($identifiers);
        }
        if (\count($identifiers) == 1 && \count($users_ids) == 0) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Account not found');
        }
        if (\count($identifiers) > 1) {
            throw new \Ministra\Lib\RESTAPI\v1\RESTCommandException('Only one identifier allowed');
        }
        $result = true;
        foreach ($users_ids as $user_id) {
            $user = \Ministra\Lib\User::getInstance($user_id);
            $info = $user->getAccountInfo();
            $subscribe = $user->updateOptionalPackageSubscription(['subscribe' => [], 'unsubscribe' => $info['subscribed']]);
            $result = $result && $subscribe;
            \Ministra\Lib\User::clear();
        }
        return $result;
    }
}
